# History

0.3.0 (2017-10-11)
------------------

* CI with travis (aws credentials)
* First release on PyPI.

0.2.0 (2017-10-11)
------------------

* query s3 bucket metadata is available
* filter s3 bucket metadata is available
* regex are available
* export s3 bucket metadata is available
* select unit to display s3 bucket metadata is available
* a CLI is available


0.1.0 (2017-09-10)
------------------

* First release on github.
